export_workflow_module

Macro export_workflow_module 

macro_rules! export_workflow_module {
    ([$($workflow:ty),+ $(,)?]) => { ... };
    ([$($workflow:ty),+ $(,)?], interceptor_constructors = [$($constructor:expr),* $(,)?] $(,)?) => { ... };
}
Export one or more workflow implementations as a component-model workflow module.

Component-side workflow interceptor constructors can be supplied with interceptor_constructors = [constructor]. Each constructor receives a read-only workflow context and is invoked for every workflow instance.