ContinueAsNewOptions

Struct ContinueAsNewOptions 

#[non_exhaustive]
pub struct ContinueAsNewOptions { pub workflow_type: Option<String>, pub task_queue: Option<String>, pub run_timeout: Option<Duration>, pub task_timeout: Option<Duration>, pub backoff_start_interval: Option<Duration>, pub memo: Option<HashMap<String, Payload>>, pub headers: Option<HashMap<String, Payload>>, pub search_attributes: Option<SearchAttributes>, pub retry_policy: Option<RetryPolicy>, pub versioning_intent: Option<VersioningIntent>, pub initial_versioning_behavior: Option<ContinueAsNewVersioningBehavior>, }
Options for continuing a workflow as a new execution.

Unset fields inherit the current workflow’s values where applicable.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
workflow_type: Option<String>

Override the workflow type for the new execution. If None, reuses the current type.

task_queue: Option<String>

Task queue for the new execution. If None, reuses the current task queue.

run_timeout: Option<Duration>

Timeout for a single run of the new workflow.

task_timeout: Option<Duration>

Timeout of a single workflow task.

backoff_start_interval: Option<Duration>

Delay before the first workflow task of the continued run is scheduled.

memo: Option<HashMap<String, Payload>>

If set, the new workflow will have this memo. If None, reuses the current memo.

headers: Option<HashMap<String, Payload>>

If set, the new workflow will have these headers.

search_attributes: Option<SearchAttributes>

If set, the new workflow will have these search attributes. If None, reuses the current search attributes.

retry_policy: Option<RetryPolicy>

If set, the new workflow will have this retry policy. If None, reuses the current policy.

versioning_intent: Option<VersioningIntent>

Whether the new workflow should run on a worker with a compatible build id.

initial_versioning_behavior: Option<ContinueAsNewVersioningBehavior>

Versioning behavior to use for the first workflow task of the new run.

This experimental option is only meaningful for workers using worker deployment versioning. AutoUpgrade routes the new run to the current deployment version; UseRampingVersion routes it to the ramping deployment version when one is configured.

Implementations

Source

impl ContinueAsNewOptions

pub fn builder() -> ContinueAsNewOptionsBuilder

Create an instance of ContinueAsNewOptions using the builder syntax