pub struct ExternalWorkflowHandle { /* private fields */ }Expand description
Handle to an external workflow for sending signals or requesting cancellation.
Obtained via SyncWorkflowContext::external_workflow or
WorkflowContext::external_workflow.
Implementations
Sourceimpl ExternalWorkflowHandle
impl ExternalWorkflowHandle
Sourcepub fn workflow_id(&self) -> &str
pub fn workflow_id(&self) -> &str
The workflow ID of the external workflow.
Sourcepub fn run_id(&self) -> Option<&str>
pub fn run_id(&self) -> Option<&str>
The run ID of the external workflow, or None if targeting the latest run.
Sourcepub fn signal<S: SignalDefinition>(
&self,
signal: S,
input: S::Input,
) -> impl CancellableFuture<Result<(), WorkflowSignalError>> + 'static
pub fn signal<S: SignalDefinition>( &self, signal: S, input: S::Input, ) -> impl CancellableFuture<Result<(), WorkflowSignalError>> + 'static
Send a signal to the external workflow.
Sourcepub fn cancel(
&self,
reason: Option<String>,
) -> impl FusedFuture<Output = CancelExternalWfResult>
pub fn cancel( &self, reason: Option<String>, ) -> impl FusedFuture<Output = CancelExternalWfResult>
Request cancellation of the external workflow.