pub struct WorkflowCancellationToken { /* private fields */ }Expand description
A deterministic cancellation token for workflow operations.
Tokens created with WorkflowCancellationToken::new are detached from workflow
cancellation. Use WorkflowCancellationToken::child_token to create a token that is
cancelled when its parent is cancelled.
Implementations
Sourceimpl WorkflowCancellationToken
impl WorkflowCancellationToken
Sourcepub fn child_token(&self) -> Self
pub fn child_token(&self) -> Self
Create a token that is cancelled when this token is cancelled.
Sourcepub fn cancel_with_reason(&self, reason: impl Into<String>)
pub fn cancel_with_reason(&self, reason: impl Into<String>)
Cancel this token with a reason.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Return whether this token has been cancelled.
Sourcepub fn reason(&self) -> Option<String>
pub fn reason(&self) -> Option<String>
Return the first cancellation reason, if one was provided.
Sourcepub fn cancelled(&self) -> impl FusedFuture<Output = ()> + '_
pub fn cancelled(&self) -> impl FusedFuture<Output = ()> + '_
Return a future that resolves when this token is cancelled.