#[non_exhaustive]pub struct HandleSignalInput { /* private fields */ }Expand description
Input passed to WorkflowInterceptor::handle_signal.
Implementations
Sourceimpl HandleSignalInput
impl HandleSignalInput
Sourcepub fn input_ref<T: Any>(&self) -> Option<&T>
pub fn input_ref<T: Any>(&self) -> Option<&T>
Attempt to access the decoded input as a concrete type.
Sourcepub fn input_mut<T: Any>(&mut self) -> Option<&mut T>
pub fn input_mut<T: Any>(&mut self) -> Option<&mut T>
Attempt to mutably access the decoded input as a concrete type.
Sourcepub fn headers(&self) -> &HashMap<String, Payload>
pub fn headers(&self) -> &HashMap<String, Payload>
Headers attached to this handler invocation.
Sourcepub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
pub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
Mutably access headers attached to this handler invocation.