#[non_exhaustive]pub struct InitializeWorkflowInput { /* private fields */ }Expand description
Input passed to WorkflowInterceptor::initialize_workflow.
The decoded input provided to workflow’s #[init] method.
If a workflow has no #[init], inputs are instead passed to WorkflowInterceptor::execute.
Implementations
Sourceimpl InitializeWorkflowInput
impl InitializeWorkflowInput
Sourcepub fn input_ref<T: Any>(&self) -> Option<&T>
pub fn input_ref<T: Any>(&self) -> Option<&T>
Attempt to access the decoded workflow input as a concrete type.
Sourcepub fn input_mut<T: Any>(&mut self) -> Option<&mut T>
pub fn input_mut<T: Any>(&mut self) -> Option<&mut T>
Attempt to mutably access the decoded workflow input as a concrete type.
Sourcepub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
pub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
Mutably access headers attached to the workflow execution.