#[non_exhaustive]pub struct SignalWorkflowInput { /* private fields */ }Expand description
Input passed to WorkflowInterceptor::signal_workflow.
Implementations
Sourceimpl SignalWorkflowInput
impl SignalWorkflowInput
Sourcepub fn signal_name(&self) -> &str
pub fn signal_name(&self) -> &str
Signal name.
Sourcepub fn signal_name_mut(&mut self) -> &mut String
pub fn signal_name_mut(&mut self) -> &mut String
Mutably access the signal name.
Sourcepub fn target(&self) -> &SignalWorkflowTarget
pub fn target(&self) -> &SignalWorkflowTarget
Signal target.
Sourcepub fn target_mut(&mut self) -> &mut SignalWorkflowTarget
pub fn target_mut(&mut self) -> &mut SignalWorkflowTarget
Mutably access the signal target.
Sourceimpl SignalWorkflowInput
impl SignalWorkflowInput
Sourcepub fn input_ref<T: Any>(&self) -> Option<&T>
pub fn input_ref<T: Any>(&self) -> Option<&T>
Attempt to access the decoded input as a concrete type.
Sourcepub fn input_mut<T: Any>(&mut self) -> Option<&mut T>
pub fn input_mut<T: Any>(&mut self) -> Option<&mut T>
Attempt to mutably access the decoded input as a concrete type.
Sourcepub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
pub fn headers_mut(&mut self) -> &mut HashMap<String, Payload>
Mutably access headers attached to this outbound call.