WorkflowOutboundValue

Trait WorkflowOutboundValue 

pub trait WorkflowOutboundValue: Any {
    // Required methods
    fn as_any(&self) -> &dyn Any;
    fn into_any(self: Box<Self>) -> Box<dyn Any>;
}
Type-erased output returned by an intercepted outbound workflow call.

Required Methods

fn as_any(&self) -> &dyn Any

Access the concrete value through Any.

fn into_any(self: Box<Self>) -> Box<dyn Any>

Convert this value into Any for a consuming downcast.

Implementations

Source

impl dyn WorkflowOutboundValue

pub fn downcast_ref<T: Any>(&self) -> Option<&T>

Attempt to access the output as a concrete type.

pub fn downcast<T: Any>(self: Box<Self>) -> Result<Box<T>, Box<dyn Any>>

Attempt to convert the output into a concrete type.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors