Temporal workflow authoring APIs and runtime glue.
Re-exports
pub use workflows::join_all;pub use temporalio_common_wasm as common;
Modules
- workflow_
interceptors - Intercept inbound and outbound calls made during workflow execution.
- workflows
- Functionality related to defining and interacting with workflows
Macros
- export_
workflow_ module - Export one or more workflow implementations as a component-model workflow module.
- join
- Deterministic
join!for use in Temporal workflows. - select
- Deterministic
select!for use in Temporal workflows.
Structs
- Activity
Options - Options for scheduling an activity
- Base
Workflow Context - Non-generic base context containing all workflow execution infrastructure.
- Child
Workflow Options - Options for scheduling a child workflow
- Continue
AsNew Options - Options for continuing a workflow as a new execution.
- External
Workflow Handle - Handle to an external workflow for sending signals or requesting cancellation.
- Local
Activity Options - Options for scheduling a local activity
- Memo
- A collection of memo payloads that can be deserialized into typed values.
- Memo
Value - A typed value used in a workflow memo update.
- Memo
Values - A complete set of memo values for a new workflow execution.
- Namespaced
Workflow Info - Information about a parent workflow.
- Nexus
Operation Options - Options for Nexus Operations
- Retry
Policy - Options for retrying workflows and activities.
- Signal
Workflow Options - Options for signaling a workflow from another workflow.
- Start
Child Workflow Output - Output produced when an intercepted child workflow successfully starts.
- Started
Child Workflow - Child workflow in started state.
- Started
Nexus Operation - Handle to a started Nexus operation.
- Sync
Workflow Context - Context provided to synchronous signal and update handlers.
- Timer
Options - Options for timer
- Wait
Condition Options - Options for waiting on a workflow condition.
- Workflow
Cancellation Error - Returned when a cancellable workflow wait is cancelled.
- Workflow
Cancellation Token - A deterministic cancellation token for workflow operations.
- Workflow
Context - Used within workflows to issue commands, get info, etc.
- Workflow
Context View - Read-only view of workflow context for use in init and query handlers.
Enums
- Activity
Cancellation Type - Controls when activity cancellation is reported back to a workflow.
- Activity
Close Timeouts - Represents Activity schedule-to-close and start-to-close timeouts for the purposes of specifying Activity options. Specifying at least one of them is required, but specifying both is also allowed. Note that this type does not cover all available timeout options for an Activity.
- Activity
Execution Error - Error type for activity execution outcomes.
- Child
Workflow Cancellation Type - Controls when child-workflow cancellation is reported to its parent.
- Child
Workflow Execution Error - Error returned when a child workflow execution fails.
- Child
Workflow Start Error - Error returned when starting a child workflow fails.
- Continue
AsNew Versioning Behavior - Versioning behavior to use for the first workflow task of a new continue-as-new run.
- Nexus
Operation Cancellation Type - Controls when Nexus operation cancellation is reported to a workflow.
- Parent
Close Policy - Controls what happens to a child workflow when its parent closes.
- Retry
State - Describes why a retry did or did not occur.
- Start
Child Workflow Execution Failed Cause - Possible causes of failure to start a child workflow
- Timeout
Type - Identifies which timeout expired.
- Timer
Result - Result of awaiting on a timer
- Versioning
Intent - Selects the worker versioning behavior intended for a command.
- Workflow
IdReuse Policy - Controls whether a closed workflow ID may be reused.
- Workflow
Signal Error - Error returned when signaling a workflow fails.
- Workflow
Termination - Represents ways a workflow can terminate without producing a normal result.
Traits
- Cancellable
Future - A Future that can be cancelled. Used in the prototype SDK for cancelling operations like timers and activities.
- Cancellable
Future With Reason - A Future that can be cancelled with a reason
- Workflow
Random Value - A numeric value that can be generated by
WorkflowContext::random.
Type Aliases
- Workflow
Result - The result of running a workflow.
Attribute Macros
- init
- Marks a method within a
#[workflow_methods]impl block as the initialization method. This attribute is processed by the#[workflow_methods]macro and should not be used standalone. - query
- Marks a method within a
#[workflow_methods]impl block as a query handler. This attribute is processed by the#[workflow_methods]macro and should not be used standalone. - run
- Marks a method within a
#[workflow_methods]impl block as the main run method. This attribute is processed by the#[workflow_methods]macro and should not be used standalone. - signal
- Marks a method within a
#[workflow_methods]impl block as a signal handler. This attribute is processed by the#[workflow_methods]macro and should not be used standalone. - update
- Marks a method within a
#[workflow_methods]impl block as an update handler. This attribute is processed by the#[workflow_methods]macro and should not be used standalone. - update_
validator - Marks a method within a
#[workflow_methods]impl block as a validator for an update handler. This attribute is processed by the#[workflow_methods]macro and should not be used standalone. - workflow
- Marks a struct as a workflow definition.
- workflow_
methods - Defines workflow methods for a workflow struct. Using this macro requires that
you also depend on the
temporalio_sdkcrate.