Temporal workflow authoring APIs and runtime glue.
Re-exports
pub use workflows::join_all;pub use temporalio_common_wasm as common;
Modules
- workflows
- Functionality related to defining and interacting with workflows
Macros
- export_
workflow_ module - Export one or more workflow implementations as a component-model workflow module.
- join
- Deterministic
join!for use in Temporal workflows. - select
- Deterministic
select!for use in Temporal workflows.
Structs
- Activity
Options - Options for scheduling an activity
- Base
Workflow Context - Non-generic base context containing all workflow execution infrastructure.
- Child
Workflow Options - Options for scheduling a child workflow
- Continue
AsNew Options - Options for continuing a workflow as a new execution.
- External
Workflow Handle - Handle to an external workflow for sending signals or requesting cancellation.
- Local
Activity Options - Options for scheduling a local activity
- Nexus
Operation Options - Options for Nexus Operations
- Parent
Workflow Info - Information about a parent workflow.
- Root
Workflow Info - Information about the root workflow in an execution chain.
- Signal
- Information needed to send a specific signal
- Signal
Data - Data contained within a signal
- Started
Child Workflow - Child workflow in started state.
- Sync
Workflow Context - Context provided to synchronous signal and update handlers.
- Timer
Options - Options for timer
- Workflow
Context - Used within workflows to issue commands, get info, etc.
- Workflow
Context View - Read-only view of workflow context for use in init and query handlers.
Enums
- Activity
Close Timeouts - The timeouts applied to an activity’s completion.
- Activity
Execution Error - Error type for activity execution outcomes.
- Child
Workflow Execution Error - Error returned when a child workflow execution fails.
- Child
Workflow Start Error - Error returned when starting a child workflow fails.
- Continue
AsNew Versioning Behavior - Versioning behavior to use for the first workflow task of a new continue-as-new run.
- Start
Child Workflow Execution Failed Cause - Possible causes of failure to start a child workflow
- Timer
Result - Result of awaiting on a timer
- Workflow
Signal Error - Error returned when signaling a workflow fails.
- Workflow
Termination - Represents ways a workflow can terminate without producing a normal result.
Traits
- Cancellable
Future - A Future that can be cancelled. Used in the prototype SDK for cancelling operations like timers and activities.
Type Aliases
- Workflow
Result - The result of running a workflow.
Attribute Macros
- init
- Marks a method within a
#[workflow_methods]impl block as the initialization method. This attribute is processed by the#[workflow_methods]macro and should not be used standalone. - query
- Marks a method within a
#[workflow_methods]impl block as a query handler. This attribute is processed by the#[workflow_methods]macro and should not be used standalone. - run
- Marks a method within a
#[workflow_methods]impl block as the main run method. This attribute is processed by the#[workflow_methods]macro and should not be used standalone. - signal
- Marks a method within a
#[workflow_methods]impl block as a signal handler. This attribute is processed by the#[workflow_methods]macro and should not be used standalone. - update
- Marks a method within a
#[workflow_methods]impl block as an update handler. This attribute is processed by the#[workflow_methods]macro and should not be used standalone. - update_
validator - Marks a method within a
#[workflow_methods]impl block as a validator for an update handler. This attribute is processed by the#[workflow_methods]macro and should not be used standalone. - workflow
- Marks a struct as a workflow definition.
- workflow_
methods - Defines workflow methods for a workflow struct. Using this macro requires that
you also depend on the
temporalio_sdkcrate.