WorkflowTermination

Enum WorkflowTermination 

pub enum WorkflowTermination {
    Cancelled,
    Evicted,
    ContinueAsNew(Box<ContinueAsNewRequest>),
    Failed(OutgoingWorkflowError),
}
Represents ways a workflow can terminate without producing a normal result.

Payload conversion errors returned by workflow operations propagated directly into WorkflowTermination, such as with ?, will fail the current Workflow Task so it can be retried.

Wrap an error in an ApplicationFailure to explicitly fail the Workflow Execution.

Variants



Cancelled



Evicted



ContinueAsNew(Box<ContinueAsNewRequest>)



Failed(OutgoingWorkflowError)

Implementations

Source

impl WorkflowTermination

pub fn continue_as_new(can: ContinueAsNewRequest) -> Self

pub fn failed_application(err: ApplicationFailure) -> Self