macro_rules! export_workflow_module {
([$($workflow:ty),+ $(,)?]) => { ... };
}Expand description
Export one or more workflow implementations as a component-model workflow module.
macro_rules! export_workflow_module {
([$($workflow:ty),+ $(,)?]) => { ... };
}Export one or more workflow implementations as a component-model workflow module.